Package 'msconverteR'

Title: Convert vendor specific mass spectrometry files to mzML
Description: Use the pwiz docker container to convert vendor specific mass spectrometry files to .mzML from within the R console on Linux systems.
Authors: Tom Wilson [aut, cre]
Maintainer: Tom Wilson <[email protected]>
License: GPL (>= 3)
Version: 0.1.2
Built: 2026-05-29 09:58:45 UTC
Source: https://github.com/wilsontom/msconverteR

Help Index


Covert Files

Description

Convert vendor specific mass spectrometry files to the open .mzML format. This functions makes a system call to docker in order to convert files. Conversion arguments should be supplied to the args parameter exactly as they would be for msconvert but omitting the --filter prefix.

Usage

convert_files(files, outpath = NULL, msconvert_args = c(), docker_args = c())

Arguments

files

the absolute filepath vendor specific files to be converted

outpath

an optional filepath where .mzML files will be saved to. If NULL then .mzML files are saved to the same location as input files.

msconvert_args

a character vector of arguments to pass to msconvert.

docker_args

additional arguments to pass to ⁠docker run⁠

Details

For example to convert a file with vendor specific centroiding only;

convert_files(rawFiles, outpath = NULL, msconvert_args = 'peakPicking true 1-')

To only retain positive mode data;

convert_files(rawFiles, outpath = NULL, msconvert_args = c('peakPicking true 1-', 'polarity positive'))

When converting multiple files, all input files must be located in the same directory so they can be mounted into the container together.


Get Proteowizard (pwiz) Docker Container

Description

Pull the pwiz docker container (chambm/pwiz-skyline-i-agree-to-the-vendor-licenses:latest) from Docker Hub.

Usage

get_pwiz_container()